]> git.sesse.net Git - cubemap/blobdiff - server.h
Add support for forced prebuffering.
[cubemap] / server.h
index 963aca9e36d9ca7c069871ad855bcb89a028f92a..49f9d51badedd68c02ae2e7436b6807f1eccb060 100644 (file)
--- a/server.h
+++ b/server.h
@@ -23,7 +23,6 @@ struct Stream;
 #define MAX_CLIENT_REQUEST 16384
 
 class CubemapStateProto;
-class MarkPool;
 class StreamProto;
 
 class Server : public Thread {
@@ -39,32 +38,32 @@ public:
                        const std::string &http_header,
                        const std::string &stream_header);
 
// Set that the given stream should use the given mark pool from now on.
        // NOTE: This should be set before any clients are connected!
-       void set_mark_pool(int stream_index, MarkPool *mark_pool);
+       void set_pacing_rate(int stream_index, uint32_t pacing_rate);
 
        // These will be deferred until the next time an iteration in do_work() happens,
        // and the order between them are undefined.
        // XXX: header should ideally be ordered with respect to data.
        void add_client_deferred(int sock);
-       void add_data_deferred(int stream_index, const char *data, size_t bytes);
+       void add_data_deferred(int stream_index, const char *data, size_t bytes, StreamStartSuitability suitable_for_stream_start);
 
        // These should not be called while running, since that would violate
        // threading assumptions (ie., that epoll is only called from one thread
        // at the same time).
        CubemapStateProto serialize();
        void add_client_from_serialized(const ClientProto &client);
-       int add_stream(const std::string &url, size_t bytes_received, Stream::Encoding encoding);
+       int add_stream(const std::string &url, size_t bytes_received, size_t prebuffering_bytes, Stream::Encoding encoding);
        int add_stream_from_serialized(const StreamProto &stream, int data_fd);
        int lookup_stream_by_url(const std::string &url) const;
        void set_backlog_size(int stream_index, size_t new_size);
        void set_encoding(int stream_index, Stream::Encoding encoding);
 
 private:
-       // Mutex protecting queued_add_clients and streams[..]->queued_data.
+       // Mutex protecting queued_add_clients.
        // Note that if you want to hold both this and <mutex> below,
        // you will need to take <mutex> before this one.
-       mutable pthread_mutex_t queued_data_mutex;
+       mutable pthread_mutex_t queued_clients_mutex;
 
        // Deferred commands that should be run from the do_work() thread as soon as possible.
        // We defer these for two reasons:
@@ -75,7 +74,7 @@ private:
        //    add_data(), since they want to do add_data() rather often, and <mutex>
        //    can be taken a lot of the time.
        //      
-       // Protected by <queued_data_mutex>.
+       // Protected by <queued_clients_mutex>.
        std::vector<int> queued_add_clients;
 
        // All variables below this line are protected by the mutex.
@@ -39,32 +38,32 @@ public:
                        const std::string &stream_header);
 
-       // Set that the given stream should use the given mark pool from now on.
+       // Set that the given stream should use the given max pacing rate from now on.
        // NOTE: This should be set before any clients are connected!